/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.geant.idpextension.oidc.attribute.resolver.spring.enc.impl;

import java.util.Map;

import javax.annotation.Nonnull;

import org.geant.idpextension.oidc.attribute.transcoding.OIDCAttributeTranscoder;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

import net.shibboleth.idp.attribute.resolver.spring.enc.BaseAttributeEncoderParser;
import net.shibboleth.utilities.java.support.primitive.StringSupport;

/**
 * Base class for Spring bean definition parser for OIDC attribute encoders.
 */
public abstract class BaseOIDCAttributeEncoderParser extends BaseAttributeEncoderParser {
    
    /** {@inheritDoc} */
    @Override
    protected void doParse(@Nonnull final Element config, @Nonnull final ParserContext parserContext,
            @Nonnull final Map<String,Object> rule) {
        
        if (config.hasAttributeNS(null, "name")) {
            rule.put(OIDCAttributeTranscoder.PROP_NAME,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "name")));
        }
        
        if (config.hasAttributeNS(null, "asArray")) {
            rule.put(OIDCAttributeTranscoder.PROP_ASARRAY,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "asArray")));
        }
        
        if (config.hasAttributeNS(null, "asInt")) {
            rule.put(OIDCAttributeTranscoder.PROP_ASINTEGER,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "asInt")));
        }

        if (config.hasAttributeNS(null, "asBoolean")) {
            rule.put(OIDCAttributeTranscoder.PROP_ASBOOLEAN,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "asBoolean")));
        }
        
        if (config.hasAttributeNS(null, "stringDelimiter")) {
            rule.put(OIDCAttributeTranscoder.PROP_STRING_DELIMITER,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "stringDelimiter")));
        }
        
        if (config.hasAttributeNS(null, "setToToken")) {
            rule.put(OIDCAttributeTranscoder.PROP_IN_TOKEN,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "setToToken")));
        }
                
        if (config.hasAttributeNS(null, "placeToIDToken")) {
            rule.put(OIDCAttributeTranscoder.PROP_FORCE_ID_TOKEN,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "placeToIDToken")));
        }
        
        if (config.hasAttributeNS(null, "denyUserinfo")) {
            rule.put(OIDCAttributeTranscoder.PROP_DENY_USERINFO,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "denyUserinfo")));
        }
    }
    
}