/*
 * Copyright (c) 2017 - 2020, GÉANT
 *
 * Licensed under the Apache License, Version 2.0 (the “License”); you may not
 * use this file except in compliance with the License. You may obtain a copy
 * of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an “AS IS” BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.geant.idpextension.oidc.attribute.resolver.spring.enc.impl;

import java.util.Map;

import javax.annotation.Nonnull;
import javax.xml.namespace.QName;

import org.geant.idpextension.oidc.attribute.transcoding.impl.OIDCScopedStringAttributeTranscoder;
import org.springframework.beans.factory.config.BeanReference;
import org.springframework.beans.factory.config.RuntimeBeanReference;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

import net.shibboleth.utilities.java.support.primitive.StringSupport;

/**
 * Spring bean definition parser for {@link OIDCScopedStringAttributeTranscoder}.
 */
public class OIDCScopedStringEncoderParser extends BaseOIDCAttributeEncoderParser {

    /** Schema type name. */
    @Nonnull
    public static final QName TYPE_NAME = new QName(AttributeEncoderNamespaceHandler.NAMESPACE, "OIDCScopedString");

    /** {@inheritDoc} */
    @Override protected void doParse(@Nonnull final Element config, @Nonnull final ParserContext parserContext,
            @Nonnull final Map<String,Object> rule) {
        super.doParse(config, parserContext, rule);

        if (config.hasAttributeNS(null, "scopeDelimiter")) {
            rule.put(OIDCScopedStringAttributeTranscoder.PROP_SCOPE_DELIMITER,
                    StringSupport.trimOrNull(config.getAttributeNS(null, "scopeDelimiter")));
        }
        
    }

    /** {@inheritDoc} */
    @Override
    protected BeanReference buildTranscoder() {
        return new RuntimeBeanReference("OIDCScopedStringTranscoder");
    }

}